@@ -555,26 +555,42 @@ rm seqkit_fish.tsv
 # ------------------------------------------------------------
 
 # Regression test for sana/fasta
-#fun(){
-#	awk '{print ">" $1 "\n" $2}' tests/scat_test.tsv > tests/sana_test_input.fas
-#	seqkit sana -i fasta tests/sana_test_input.fas > tests/sana_output.fas
-#}
-#run sana_fasta_regression fun
-#cmp tests/sana_output.fas tests/sana_ground.fas
-#assert_equal $? 0
-#rm -f tests/sana_output.fas tests/sana_test_input.fas
+fun(){
+	awk '{print ">" $1 "\n" $2}' tests/scat_test.tsv > tests/sana_test_input.fas
+	$app sana -i fasta tests/sana_test_input.fas > tests/sana_output.fas
+}
+run sana_fasta_regression fun
+cmp tests/sana_output.fas tests/sana_ground.fas
+assert_equal $? 0
+rm -f tests/sana_output.fas tests/sana_test_input.fas
 
 # Regression test for sana/fastq
 fun(){
 	awk '{print "@" $1 "\n" $2 "\n+\n" $3}' tests/scat_test.tsv > tests/sana_test_input.fq
-	#seqkit sana -i fastq tests/sana_test_input.fq > tests/sana_output.fq
-	seqkit sana tests/sana_test_input.fq > tests/sana_output.fq
+	# $app  sana -i fastq tests/sana_test_input.fq > tests/sana_output.fq
+	$app  sana tests/sana_test_input.fq > tests/sana_output.fq
 }
-run sana_fastq_regression fun
+run sana_fastq_regression_empty_line fun
 cmp tests/sana_output.fq tests/sana_ground.fq
 assert_equal $? 0
 rm -f tests/sana_output.fq tests/sana_test_input.fq
 
+# Regression test for sana/fasta empty file issue
+fun(){
+	$app  sana -j 2 -i fasta tests/empty.fx
+}
+run sana_fasta_regression_empty_line fun
+assert_equal $? 0
+
+
+# Regression test for sana/fastq empty file issue
+fun(){
+	$app  sana -j 2 -i fastq tests/empty.fx
+}
+run sana_fastq_regression fun
+assert_equal $? 0
+
+
 # ------------------------------------------------------------
 #                       scat
 # ------------------------------------------------------------
@@ -585,11 +601,11 @@ fun(){
 	rm -fr $BASE 
 	rm -f tests/scat_test_all.fas tests/scat_output.fas
         mkdir -p $BASE
-	(seqkit scat -j 4 -i fasta $BASE > tests/scat_output.fas)&
+	($app scat -j 4 -i fasta $BASE > tests/scat_output.fas)&
 	SCAT_PID=$!
         BAK=$IFS
         IFS=$'\n'
-	SIZE=5
+	SIZE=3
         for i in `seq 0 $SIZE`;
         do
                 for j in `seq 0 $SIZE`;
@@ -602,27 +618,29 @@ fun(){
                                 PRE=".${RANDOM}.${i}.${j}"
                                 echo -n $l | awk -v pre="$PRE" '{print ">" $1 pre  "\n" $2}' - >> $F
                                 echo -n $l | awk -v pre="$PRE" '{print ">" $1 pre  "\n" $2}' - >> tests/scat_test_all.fas
+				sync;
                         done;
 		done;
         done;
         IFS=$BAK
-	sync
+	sync; sleep 0.5
+	$app sana -j 4 -i fasta tests/scat_test_all.fas | $app sort -n -j 1 - > tests/sorted_scat_test_all.fas
 	kill -s INT $SCAT_PID
+	sync; sleep 0.5
 	wait $SCAT_PID
-	seqkit scat -f -j 4 -i fasta $BASE | seqkit sort -n -j 4 - > tests/sorted_scat_find.fas
-	sync
-	seqkit sana -j 4 -i fasta tests/scat_test_all.fas | seqkit sort -n -j 4 - > tests/sorted_scat_test_all.fas
-	seqkit sort -n -j 4 tests/scat_output.fas > tests/sorted_scat_output.fas
+	sync; 
+	$app scat -f -j 4 -i fasta $BASE | $app sort -n -j 1 - > tests/sorted_scat_find.fas
+	$app sort -n -j 1 tests/scat_output.fas > tests/sorted_scat_output.fas
 	rm -fr $BASE
 	rm -f tests/scat_test_all.fas tests/scat_output.fas
 }
 
-#run scat_fasta fun
-#cmp tests/sorted_scat_output.fas tests/sorted_scat_test_all.fas
-#assert_equal $? 0
-#cmp tests/sorted_scat_find.fas tests/sorted_scat_test_all.fas
-#assert_equal $? 0
-#rm -f tests/sorted_scat_output.fas tests/sorted_scat_test_all.fas tests/sorted_scat_find.fas
+run scat_fasta fun
+cmp tests/sorted_scat_output.fas tests/sorted_scat_test_all.fas
+assert_equal $? 0
+cmp tests/sorted_scat_find.fas tests/sorted_scat_test_all.fas
+assert_equal $? 0
+rm -f tests/sorted_scat_output.fas tests/sorted_scat_test_all.fas tests/sorted_scat_find.fas
 
 # Regression test for scat/fastq
 fun(){
@@ -630,11 +648,11 @@ fun(){
 	rm -fr $BASE 
 	rm -f tests/scat_test_all.fq tests/scat_output.fq
         mkdir -p $BASE
-	(seqkit scat -j 4 -i fastq $BASE > tests/scat_output.fq)&
+	($app scat -j 4 -i fastq $BASE > tests/scat_output.fq)&
 	SCAT_PID=$!
         BAK=$IFS
         IFS=$'\n'
-	SIZE=5
+	SIZE=3
         for i in `seq 0 $SIZE`;
         do
                 for j in `seq 0 $SIZE`;
@@ -652,23 +670,23 @@ fun(){
         done;
         IFS=$BAK
 	sync; sleep 0.5
+	$app sana -j 4 -i fastq tests/scat_test_all.fq > tests/scat_test_all_sana.fq
 	kill -s INT $SCAT_PID
 	wait $SCAT_PID
-	seqkit scat -f -j 4 -i fastq $BASE | seqkit sort -n -j 4 - > tests/sorted_scat_find.fq
-	sync
-	seqkit sana -j 4 -i fastq tests/scat_test_all.fq > tests/scat_test_all_sana.fq
-	seqkit sort -n -j 4 tests/scat_test_all_sana.fq > tests/sorted_scat_test_all.fq
-	seqkit sort -n -j 4 tests/scat_output.fq > tests/sorted_scat_output.fq
+	sync; sleep 0.5
+	$app scat -f -j 4 -i fastq $BASE | $app sort -n -j 1 - > tests/sorted_scat_find.fq
+	$app sort -n -j 1 tests/scat_test_all_sana.fq > tests/sorted_scat_test_all.fq
+	$app sort -n -j 1 tests/scat_output.fq > tests/sorted_scat_output.fq
 	rm -fr $BASE
 	rm -f tests/scat_test_all.fq tests/scat_output.fq
 }
 
-#run scat_fastq fun
-#cmp tests/sorted_scat_output.fq tests/sorted_scat_test_all.fq
-#assert_equal $? 0
-#cmp tests/sorted_scat_find.fq tests/sorted_scat_test_all.fq
-#assert_equal $? 0
-#rm -f tests/sorted_scat_output.fq tests/sorted_scat_test_all.fq tests/sorted_scat_find.fq
+run scat_fastq fun
+cmp tests/sorted_scat_output.fq tests/sorted_scat_test_all.fq
+assert_equal $? 0
+cmp tests/sorted_scat_find.fq tests/sorted_scat_test_all.fq
+assert_equal $? 0
+rm -f tests/sorted_scat_output.fq tests/sorted_scat_test_all.fq tests/sorted_scat_find.fq tests/scat_test_all_sana.fq
 
 # ------------------------------------------------------------
 #                       faidx
@@ -682,14 +700,14 @@ fun(){
     $app faidx $file $(paste -s -d ' ' $idFile) > $outFile
 }
 run faidx_id fun
-assert_equal $($app grep -f $idFile $file | seqkit seq -i | seqkit sort | md5sum | cut -d" " -f 1) $(cat $outFile | seqkit sort | md5sum | cut -d" " -f 1)
+assert_equal $($app grep -f $idFile $file | $app seq -i | $app sort | md5sum | cut -d" " -f 1) $(cat $outFile | $app sort | md5sum | cut -d" " -f 1)
 rm $outFile
 
 fun(){
     $app faidx $file $(paste -s -d ' ' $idFile) -f > $outFile
 }
 run faidx_full_head fun
-assert_equal $($app grep -f $idFile $file | seqkit sort | md5sum | cut -d" " -f 1) $(cat $outFile | seqkit sort | md5sum | cut -d" " -f 1)
+assert_equal $($app grep -f $idFile $file | $app sort | md5sum | cut -d" " -f 1) $(cat $outFile | $app sort | md5sum | cut -d" " -f 1)
 rm $outFile
 
 
@@ -698,5 +716,5 @@ fun(){
     $app faidx $file "${ref}:5--5" -f > $outFile
 }
 run faidx_region fun
-assert_equal $($app grep -p $ref $file | seqkit subseq -r 5:-5 | seqkit seq -s -w 0) $(cat $outFile | seqkit seq -s -w 0)
+assert_equal $($app grep -p $ref $file | $app subseq -r 5:-5 | $app seq -s -w 0) $(cat $outFile | $app seq -s -w 0)
 rm $idFile $outFile
